# Version 0.1.8
* Make device names lowercase. Most important release ever.

# Version 0.1.7
* Add join_timeout and debug parameters to discover()
* Remove Kivy UI and relocate to https://www.github.com/mghelton/w3mo-kivy

# Version 0.1.6
* Internal testing release, not for use in production

# Version 0.1.5
* Add simple Kivy UI
* Set threads to daemon and join timeout

# Version 0.1.4
* Update interactive "shell"
* Discovery only works on /24 (255.255.255.0) subnets, more subnet options coming soon.

# Version 0.1.3
* update documentation
* add device discovery for local subnet

# Version 0.1.0
* works on "Wemo Mini" with firmware 2.0.11452 - 04/11/2020
